@@ -1,9 +1,9 @@
 package Monitoring::GLPlugin::DB::TableItem;
-our @ISA = qw(Monitoring::GLPlugin::TableItem Monitoring::GLPlugin::DB);
+our @ISA = qw(Monitoring::GLPlugin::DB::CSF Monitoring::GLPlugin::TableItem Monitoring::GLPlugin::DB);
 use strict;
 
 sub globalize_errors {
-  my $self = shift;
+  my ($self) = @_;
   #delete *{'add_message'};
   {
     no strict 'refs';
@@ -15,7 +15,7 @@ sub globalize_errors {
 }
 
 sub localize_errors {
-  my $self = shift;
+  my ($self) = @_;
   $self->{messages} = { 
       ok=> [],
       warning => [],
